@@ -2,8 +2,6 @@
 from .jurisdiction import JurisdictionImporter
 from .organizations import OrganizationImporter
 from .people import PersonImporter
-from .posts import PostImporter
-from .memberships import MembershipImporter
 from .bills import BillImporter
 from .vote_events import VoteEventImporter
 from .events import EventImporter
