@@ -1,7 +1,7 @@
 # flake8: noqa
 from .jurisdiction import Jurisdiction, JurisdictionScraper
 from .popolo import Membership, Organization, Person, Post
-from .vote_event import VoteEvent, OrderVoteEvent
+from .vote_event import VoteEvent
 from .bill import Bill
 from .event import Event
 from .base import Scraper, BaseBillScraper
