@@ -1,4 +1,4 @@
-from .common import links, contact_details, extras, fuzzy_date_blank
+from .common import extras, fuzzy_date_blank
 
 schema = {
     "properties": {
@@ -8,11 +8,8 @@ schema = {
         "person_name": {"type": ["string"], "minLength": 1},
         "organization_id": {"type": "string", "minLength": 1},
         "post_id": {"type": ["string", "null"]},
-        "on_behalf_of_id": {"type": ["string", "null"]},
         "start_date": fuzzy_date_blank,
         "end_date": fuzzy_date_blank,
-        "contact_details": contact_details,
-        "links": links,
         "extras": extras,
         # division & jurisdiction are additions to popolo
         "division_id": {"type": ["string", "null"]},
